*****
Video
*****

You can upload video files to the server and play them back in the browser.

Videos have a `title` a file field `original` pointing to the original video
file, an image `poster` and a list of `tags`.

If no `poster` is given, the first frame of the video after one second is used
as poster.
